@@ -1061,7 +1061,7 @@ class ExtractRawTrodesData:
     def extract_dio(self, dates, epochs, export_args=(), **kwargs):
         trodes_version = self.trodes_anim_info.trodes_version
         if trodes_version < 2:
-            export_cmd = 'exportdio'
+            export_cmd = ['exportdio']
         else:
             export_cmd = ['trodesexport', '-dio']
 
@@ -1511,6 +1511,6 @@ def get_trodes_version_from_path():
                      .stdout)
     version = (result
                .split('\\n')[0]
-               .split(' ')[-1]
+               .split(' ')[2]
                .split('.'))
     return int(version[0]), int(version[1]), int(version[2])
